from setuptools import setup


setup(name="GISIC",
      version='0.2',
      description="Gaussian Inflection Spline Interpolation Continuum",
      author='Devin D. Whitten',
      author_email='dwhitten@nd.edu',
      license="ND",
      packages=['GISIC'],
      zip_safe=False
)
